#!/bin/bash
# name: /usr/bin/poetherm.sh
# author: reinhard@finalmedia.de
# date: Do 28. Nov 21:29:43 CET 2019

test $# -lt 2 && \
echo "Beispielaufruf: $0 192.168.0.44 \
/tmp/temperature.rrd > \
/tmp/overview.png" >&2 && exit 1

title="Temperatur"
database="$2"
host="$1"

# Datenbank in Datei erzeugen, wenn noch nicht existent
test ! -f "$database" && \
rrdtool create $database --step 60 \
DS:temp:GAUGE:600:-273:5000 \
RRA:AVERAGE:0.5:1:1200 \
RRA:MIN:0.5:12:2400 \
RRA:MAX:0.5:12:2400 \
RRA:AVERAGE:0.5:12:2400 && \
chown nobody:nogroup "$database"

# Aktuelle Temperatur Daten abholen und Datenbank updaten
rrdtool update "$database" N:$(curl --connect-timeout 5 \
-s "http://$host/temp" 2>/dev/null | \
tr -dc "0-9." | head -c 64)

# Vier Graphen On-The-Fly erzeugen und als eine
# einzige PNG Datei vertikal montieren
pnmcat -tb \
<(\
rrdtool graph /dev/stdout -a PNG --title="$title" \
"DEF:temp1=$database:temp:AVERAGE" \
"LINE1:temp1#ff0000:$host" | pngtopnm \
) <(\
start="$(date -d "last week" +'%s')"
end="$(date -d "now" +'%s')"
rrdtool graph /dev/stdout -s "$start" -e "$end" \
-a PNG --title="$title (Woche)" \
"DEF:temp1=$database:temp:AVERAGE" \
"LINE1:temp1#ff0000:$host" | pngtopnm \
) <(\
start="$(date -d "last month" +'%s')"
end="$(date -d "now" +'%s')"
rrdtool graph /dev/stdout -s "$start" -e "$end" \
-a PNG --title="$title (Monat)" \
"DEF:temp1=$database:temp:AVERAGE" \
"LINE1:temp1#ff0000:$host" | pngtopnm \
) <(\
start="$(date -d "last year" +'%s')"
end="$(date -d "now" +'%s')"
rrdtool graph /dev/stdout -s "$start" -e "$end" \
-a PNG --title="$title (Jahr)" \
"DEF:temp1=$database:temp:AVERAGE" \
"LINE1:temp1#ff0000:$host" | pngtopnm \
) <(\
start="$(date -d "-5 years" +'%s')"
end="$(date -d "now" +'%s')"
rrdtool graph /dev/stdout -s "$start" -e "$end" \
-a PNG --title="$title (5 Jahre)" \
"DEF:temp1=$database:temp:AVERAGE" \
"LINE1:temp1#ff0000:$host" | pngtopnm \
) | pnmtopng

